%define major   1.3
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           fltk
Version:        1.3.6
Release:        %mkrel 2
Summary:        Fast Light Toolkit (FLTK)
Group:          System/Libraries
License:        LGPLv2+
URL:            https://www.fltk.org
Source0:        https://www.fltk.org/pub/fltk/%{version}/%{name}-%{version}-source.tar.gz
Patch0:         fltk-1.3.6-libdir-prefix.patch
Patch1:         fltk-1.3.6-remove-shared-in-libnames.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  xprop

%description
The Fast Light Toolkit ("FLTK", pronounced "fulltick") is a LGPL'd
C++ graphical user interface toolkit for X (UNIX(r)), OpenGL(r),
and Microsoft(r) Windows(r) NT 4.0, 95, or 98. It was originally
developed by Mr. Bill Spitzak and is currently maintained by a
small group of developers across the world with a central
repository in the US.

#---------------------------------------------------------------------------

%package -n %{libname}
Summary:        Fast Light Toolkit (FLTK) - main library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
The Fast Light Toolkit ("FLTK", pronounced "fulltick") is a LGPL'd
C++ graphical user interface toolkit for X (UNIX(r)), OpenGL(r),
and Microsoft(r) Windows(r) NT 4.0, 95, or 98. It was originally
developed by Mr. Bill Spitzak and is currently maintained by a
small group of developers across the world with a central
repository in the US.

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}_forms.so.%{major}{,.*}
%{_libdir}/lib%{name}_gl.so.%{major}{,.*}
%{_libdir}/lib%{name}_images.so.%{major}{,.*}

#---------------------------------------------------------------------------

%package -n %{devname}
Summary:        Fast Light Toolkit (FLTK) - development environment
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name}-fluid = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development headers and libraries for FLTK.

%files -n %{devname}
%doc README CHANGES
%doc README.CMake.txt README.Unix.txt
%{_bindir}/%{name}-config
%{multiarch_bindir}/%{name}-config
%{_datadir}/%{name}/
%{_includedir}/FL/
%{_libdir}/lib%{name}*.so
%{_mandir}/man1/%{name}-config.1*
%{_mandir}/man3/%{name}.3*

#---------------------------------------------------------------------------

%package fluid
Summary:        Fast Light User Interface Designer: GUI builder for FLTK
Group:          Development/Tools

%description fluid
FLUID (Fast Light User Interface Designer) is a graphical editor and GUI
builder that is used to produce FLTK source code. FLUID edits and saves its
state in text .fl files, which can be edited in a text editor for finer
control over display and behavior.

%files fluid
%{_bindir}/fluid
%{_datadir}/mime/packages/fluid.xml
%{_datadir}/applications/fluid.desktop
%{_iconsdir}/hicolor/*/apps/fluid.png
%{_mandir}/man1/fluid.1*

#---------------------------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake \
    -DOPTION_BUILD_SHARED_LIBS=ON \
    -DOPTION_USE_SYSTEM_ZLIB=ON \
    -DOPTION_USE_SYSTEM_LIBJPEG=ON \
    -DOPTION_USE_SYSTEM_LIBPNG=ON \
    -DFLTK_BUILD_EXAMPLES=OFF
%cmake_build

%install
%cmake_install

# Demos man pages
rm -rf %{buildroot}%{_mandir}/man6

# We don't want static libraries
find %{buildroot} -name "*.a" -delete

%multiarch_binaries %{buildroot}%{_bindir}/%{name}-config


%changelog
* Thu Mar 31 2022 umeabot <umeabot> 1.3.6-2.mga9
+ Revision: 1836248
- Mageia 9 Mass Rebuild

* Fri May 21 2021 daviddavid <daviddavid> 1.3.6-1.mga9
+ Revision: 1725988
- new version: 1.3.6
- rediff patches and use a single patch for shared and static libs

* Sat Feb 15 2020 umeabot <umeabot> 1.3.5-2.mga8
+ Revision: 1526126
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Apr 26 2019 akien <akien> 1.3.5-1.mga7
+ Revision: 1395440
- Version 1.3.5

* Sun Sep 23 2018 umeabot <umeabot> 1.3.4.2-2.mga7
+ Revision: 1297729
- Mageia 7 Mass Rebuild

* Mon Jan 01 2018 kekepower <kekepower> 1.3.4.2-1.mga7
+ Revision: 1188940
- Fixed Source0 URL
- Updated to version 1.3.4-2
- Removed _SHARED from filenames
- Renamed static files to contain _static, if they're built

* Thu Apr 28 2016 daviddavid <daviddavid> 1.3.4-0.r11608.2.mga6
+ Revision: 1007169
- devel subpackage requires fltk-fluid

* Mon Apr 25 2016 akien <akien> 1.3.4-0.r11608.1.mga6
+ Revision: 1006224
- Drop static libraries and CMakeCache.txt
- Split fluid application in subpackage
- Do not package demos man pages
- Snapshot 11608

* Thu Feb 11 2016 umeabot <umeabot> 1.3.4-0.r10852.3.mga6
+ Revision: 953955
- Mageia 6 Mass Rebuild

* Thu Sep 10 2015 fwang <fwang> 1.3.4-0.r10852.2.mga6
+ Revision: 875379
- fix libdir

* Thu Sep 10 2015 fwang <fwang> 1.3.4-0.r10852.1.mga6
+ Revision: 875354
- update file list
- upload snapshot
- upstream snapshot

* Thu Aug 20 2015 fwang <fwang> 1.3.3-14.mga6
+ Revision: 866657
- fix link lib for fltk static
- fix gl lib name
- more linkage fix
- cleanup build requires

* Thu Aug 20 2015 fwang <fwang> 1.3.3-13.mga6
+ Revision: 866623
- include use file, so that fluid is promoted

* Tue Aug 18 2015 fwang <fwang> 1.3.3-12.mga6
+ Revision: 865487
- hardcode GL for now

* Tue Aug 18 2015 fwang <fwang> 1.3.3-11.mga6
+ Revision: 865483
- show opengl libraries correctly

* Tue Aug 18 2015 fwang <fwang> 1.3.3-10.mga6
+ Revision: 865429
- fix prefix

* Mon Aug 17 2015 fwang <fwang> 1.3.3-9.mga6
+ Revision: 865314
- fix cmake libs
- fix include dir

* Mon Aug 17 2015 fwang <fwang> 1.3.3-8.mga6
+ Revision: 865274
- add upstream patch to export fl_xfont

* Mon Aug 17 2015 fwang <fwang> 1.3.3-7.mga6
+ Revision: 865258
- compatible with older cmake by installing cache file

* Mon Aug 17 2015 fwang <fwang> 1.3.3-6.mga6
+ Revision: 865248
- add more readme

* Mon Aug 17 2015 fwang <fwang> 1.3.3-5.mga6
+ Revision: 865244
- add patch from debian(#793549) for defining FLTK_FLUID_EXECUTABLE
- add conflicts with libfltk0 < 1.3.2

* Sun Aug 16 2015 fwang <fwang> 1.3.3-4.mga6
+ Revision: 865084
- there is no actural obsoletes

* Sat Aug 15 2015 fwang <fwang> 1.3.3-3.mga6
+ Revision: 864867
- fix linkage on xcursor
- turn back to cmake build
- link gl with fltk
- export ldflags
- add more br
- build with configure rather than cmake

* Fri Aug 14 2015 fwang <fwang> 1.3.3-2.mga6
+ Revision: 864633
- bump rel
- fix lib path in x64 arch
- fix man page install dir
- update libmajor
- link against xfixes
- fix linkage
- 1.3.3

* Wed Oct 15 2014 umeabot <umeabot> 1.3.2-4.mga5
+ Revision: 745655
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.2-3.mga5
+ Revision: 679241
- Mageia 5 Mass Rebuild

* Thu May 29 2014 fwang <fwang> 1.3.2-2.mga5
+ Revision: 627466
- update file list
- adopt to new freetype dir
- lock libmajor
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 fwang <fwang> 1.3.2-1.mga4
+ Revision: 475850
- new version 1.3.2

* Sun Jun 02 2013 fwang <fwang> 1.3.1-3.mga4
+ Revision: 434635
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 1.3.1-2.mga3
+ Revision: 350566
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 fwang <fwang> 1.3.1-1.mga3
+ Revision: 316388
- new version 1.3.1

* Thu Jan 26 2012 fwang <fwang> 1.3.0-3.mga2
+ Revision: 202025
- more linkage fix

* Sat Sep 10 2011 fwang <fwang> 1.3.0-2.mga2
+ Revision: 142098
- rebuild for new libpng

* Mon Jul 11 2011 fwang <fwang> 1.3.0-1.mga2
+ Revision: 122083
- do not build examples
- update file list
- build with fpic
- new version 1.3.0
- drop unused patches

* Thu Apr 14 2011 ahmad <ahmad> 1.1.10-5.mga1
+ Revision: 85479
- add more BR to enable more features (e.g. libfltk_gl.so* was missing)

* Wed Jan 12 2011 dmorgan <dmorgan> 1.1.10-4.mga1
+ Revision: 7253
- Add libx11-devel as buildrequire
- Remove X11-devel, to find the real needed br
- imported package fltk
+ ahmad <ahmad>
- imported package fltk


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1.1.10-4mdv2011.0
+ Revision: 605159
- rebuild

* Wed Feb 17 2010 Frederic Crozat <fcrozat@mandriva.com> 1.1.10-3mdv2010.1
+ Revision: 507145
- force rebuild

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 1.1.10-2mdv2010.1
+ Revision: 488754
- rebuilt against libjpeg v8

* Sat Jan 02 2010 Frederik Himpe <fhimpe@mandriva.org> 1.1.10-1mdv2010.1
+ Revision: 485154
- update to new version 1.1.10

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 1.1.9-14mdv2010.0
+ Revision: 416614
- rebuilt against libjpeg v7

* Wed Aug 12 2009 Christophe Fergeau <cfergeau@mandriva.com> 1.1.9-13mdv2010.0
+ Revision: 415413
- fix compilation with gcc 4.4

* Thu Jan 29 2009 Funda Wang <fwang@mandriva.org> 1.1.9-12mdv2009.1
+ Revision: 335174
- fix link dir

* Thu Jan 29 2009 Funda Wang <fwang@mandriva.org> 1.1.9-11mdv2009.1
+ Revision: 335142
- do not build examples
- "fltk-config --libs" should return the same result as --ldflags

* Sun Dec 14 2008 Funda Wang <fwang@mandriva.org> 1.1.9-10mdv2009.1
+ Revision: 314120
- add extra libs to fltk-config
- about to split zlib

* Sun Dec 14 2008 Funda Wang <fwang@mandriva.org> 1.1.9-9mdv2009.1
+ Revision: 314108
- set images in fltk-config

* Sun Dec 14 2008 Funda Wang <fwang@mandriva.org> 1.1.9-8mdv2009.1
+ Revision: 314101
- install manpages and documentations

* Sun Dec 14 2008 Funda Wang <fwang@mandriva.org> 1.1.9-7mdv2009.1
+ Revision: 314096
- fix include dir

* Sun Dec 14 2008 Funda Wang <fwang@mandriva.org> 1.1.9-6mdv2009.1
+ Revision: 314086
- remove wrong provides
- install fltk-config too. It is not deprecated, but missed from installing

* Thu Dec 04 2008 Helio Chissini de Castro <helio@mandriva.com> 1.1.9-4mdv2009.1
+ Revision: 310038
- Bump release to recompile
- Fixed library install with cmake
- Make package right. Since change to cmake, most of software are not
  recognizing fltk in a right way. configure SHOULD NOT be used anymore, and
  fltk-config is deprecated

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1.1.9-2mdv2009.0
+ Revision: 264466
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun May 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.9-1mdv2009.0
+ Revision: 205946
- New stable release

* Sat Jan 12 2008 Thierry Vignaud <tv@mandriva.org> 1.1.8-0.5940.1mdv2008.1
+ Revision: 149729
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Sep 06 2007 Adam Williamson <awilliamson@mandriva.org> 1.1.8-0.5940.1mdv2008.0
+ Revision: 80679
- move doc files to -devel package (lib policy)
- use Fedora license policy
- new snapshot 5940

* Thu Jun 28 2007 Adam Williamson <awilliamson@mandriva.org> 1.1.8-0.5917.1mdv2008.0
+ Revision: 45320
- correct cleanup, disable debug package build again
- try again with debug...
- close if statement
- clean up after hack, disable debug packages as generation seems broken
- use Fedora trick instead
- rediff and reintroduce x86-64 patch, seems to be needed
- new devel policy
- unversioned doc dir
- go to 1.1.x snapshot series (needed for latest flphoto)


* Fri Aug 25 2006 Gaetan Lehmann <glehmann@mandriva.org> 1.1.7-7mdv2007.0
- add cmake config files

* Tue Jun 27 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.1.7-5mdv2007.1
- Rebuild for missing packages

* Sun Jun 25 2006 Stefan van der Eijk <stefan@eijk.nu> 1.1.7-4mdv2007.1
rebuild for png

* Sat Jun 10 2006 Stefan van der Eijk <stefan@eijk.nu> 1.1.7-4mdk
- new mesa BuildRequires

* Sun May 14 2006 Stefan van der Eijk <stefan@eijk.nu> 1.1.7-3mdk
- rebuild for sparc

* Tue Mar 07 2006 Austin Acton <austin@mandriva.org> 1.1.7-2mdk
- mkrel
- enable threads
- buildreuqires alsa and GLU

* Mon Mar 06 2006 Austin Acton <austin@mandriva.org> 1.1.7-1mdk
- 1.1.7
- minor tweaks

* Sun Jan 08 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.1.6-3mdk
- Rebuild

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.1.6-2mdk
- multiarch

* Mon Dec 13 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.6-1mdk
- Updated to version 1.1.6.

* Fri Jun 04 2004 <lmontel@n2.mandrakesoft.com> 1.1.4-3mdk
- Rebuild

* Tue Jan 27 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.1.4-2mdk
- fix unpackaged files
- fix {build,}requires
- cosmetics

* Wed Oct 08 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.1.4-1mdk
- 1.1, more lib64 fixes

